#! /usr/bin/perl
#
# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


use strict;
use warnings FATAL => 'all';
use diagnostics;


require "session.pl";
require "url.pl";
require "http.pl";
require "html.pl";


# 0: sid
# 1: latest url id
# 2: cookie age
# 3: max count
# 4: cookie set date
# 5: auto reset
sub print_settings($$$$$$)
{
	my ($sid, $latest_id, $age, $count, $set, $reset) = @_;

	my $self = &URL::settings();
	my $p_reset = $reset == 1 ? " CHECKED" : "";
	my $p_count = $count;
	my $p_age = int($age / 24 / 60 / 60);

	my $l_title = &Lang::get("settings-title");
	my $l_reset = &Lang::get("settings-reset");
	my $l_count = &Lang::get("settings-count");
	my $l_age = &Lang::get("settings-age");
	my $l_ok = &Lang::get("settings-save");

	print <<EOF;
<h1>$l_title</h1>

<form method="post" action="$self">
<input type="hidden" name="set" value="1" />
<table>
	<tr>
		<th>Automatic reset</th>
		<td><input type="checkbox" name="reset"$p_reset /></td>
	</tr>
	<tr>
		<th>Max URL-count</th>
		<td><input type="text" name="count" size="8"
				value="$p_count" /></td>
	</tr>
	<tr>
		<th>Cookie age<br />(days)</th>
		<td><input type="text" name="age" size="8"
				value="$p_age" /></td>
	</tr>
	<tr>
		<td colspan="2">
			<input type="submit" value="$l_ok" />
		</td>
	</tr>
</table>
</form>
EOF
}


# 0: sid
# 1: latest url id
# 2: cookie age
# 3: max count
# 4: cookie set date
# 5: auto reset
sub set_settings($$$$$$)
{
	my ($sid, $old_latest_id, $old_age, $old_count,
			$old_set, $old_reset) = @_;

	my $new_age = &HTTP::post("age", 0);
	my $new_count = &HTTP::post("count", $old_count);
	my $new_reset = &HTTP::post("reset", $old_reset);

	if ($new_age == 0) {
		$new_age = $old_age;
	} else {
		$new_age *= 24 * 60 * 60;
	}
	$new_reset = ($new_reset =~ /^on$/i) ? 1 : 0;

	&Session::set_settings($sid, $new_age, $new_count, $new_reset);
}


sub main()
{
	my $sid;
	my $phase;

	$sid = &Session::get_session();
	&Session::check_sid($sid, &URL::session(1, &URL::settings()));

	&HTTP::print_header();
	&HTML::print_header();

	&Session::print_links();

	my ($old_url_id, $old_age, $old_count, $old_date, $old_reset) =
			&Session::get_settings($sid);

	if (&HTTP::post("set", 0) == 1) {
		&set_settings($sid, $old_url_id, $old_age, $old_count,
				$old_date, $old_reset);
		($old_url_id, $old_age, $old_count, $old_date, $old_reset) =
				&Session::get_settings($sid);
	}

	&print_settings($sid, $old_url_id, $old_age, $old_count, $old_date,
			$old_reset);
	if (&HTTP::post("set", 0) == 1) {
		printf "<p><em>%s</em></p>\n", &Lang::get("settings-updated");
	}

	&HTML::print_footer(&DB::process_time());
}


&main();
